@@ -6,7 +6,7 @@
 #ifndef _IP_VS_H
 #define _IP_VS_H
 
-#define IP_VS_VERSION_CODE            0x000800
+#define IP_VS_VERSION_CODE            0x000801
 #define NVERSION(version)                       \
         (version >> 16) & 0xFF,                 \
         (version >> 8) & 0xFF,                  \
@@ -98,7 +98,8 @@ struct ip_vs_rule_user {
 #define IP_VS_CONN_F_IN_SEQ           0x0400    /* must do input seq adjust */
 #define IP_VS_CONN_F_NO_CPORT         0x0800    /* no client port set yet */
 
-#define NFMARK_IPVS_PROPERTY	      -0x100
+/* Move it to better place one day, for now keep it unique */
+#define NFC_IPVS_PROPERTY	0x10000
 
 #ifdef __KERNEL__
 
