@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.15.2.4 2001/05/09 08:00:16 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.15.2.5 2001/06/22 15:03:08 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -600,10 +600,13 @@ int ip_vs_set_state(struct ip_vs_conn *cp,
         switch (iph->protocol) {
         case IPPROTO_ICMP:
                 ret = vs_set_state_timeout(cp, IP_VS_S_ICMP);
+		break;
         case IPPROTO_UDP:
                 ret = vs_set_state_timeout(cp, IP_VS_S_UDP);
+		break;
         case IPPROTO_TCP:
                 ret = vs_tcp_state(cp, state_off, tp);
+		break;
         default:
                 ret = -1;
         }
@@ -659,7 +662,7 @@ static int ip_vs_bypass_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
-	skb->nfmark = NFMARK_IPVS_PROPERTY;
+	skb->nfcache |= NFC_IPVS_PROPERTY;
         ip_send(skb);
 
         LeaveFunction(10);
@@ -848,7 +851,7 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
-	skb->nfmark = NFMARK_IPVS_PROPERTY;
+	skb->nfcache |= NFC_IPVS_PROPERTY;
         ip_send(skb);
 
         LeaveFunction(10);
@@ -987,7 +990,7 @@ static int ip_vs_tunnel_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
-	skb->nfmark = NFMARK_IPVS_PROPERTY;
+	skb->nfcache |= NFC_IPVS_PROPERTY;
 	ip_send(skb);
 
         LeaveFunction(10);
@@ -1049,7 +1052,7 @@ static int ip_vs_dr_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
-	skb->nfmark = NFMARK_IPVS_PROPERTY;
+	skb->nfcache |= NFC_IPVS_PROPERTY;
         ip_send(skb);
 
 #if 0000
