@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.17.2.1 2001/05/09 08:00:16 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.17.2.2 2001/06/22 15:03:08 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -525,6 +525,7 @@ static int ip_vs_leave(struct ip_vs_service *svc, struct sk_buff *skb)
                 /* transmit the first SYN packet */
                 ret = cp->packet_xmit(skb, cp);
 
+		atomic_inc(&cp->in_pkts);
                 ip_vs_conn_put(cp);
                 return ret;
         }
@@ -570,7 +571,7 @@ static unsigned int ip_vs_post_routing(unsigned int hooknum,
 {
         struct sk_buff  *skb = *skb_p;
 
-	if (skb->nfmark != NFMARK_IPVS_PROPERTY)
+	if (!(skb->nfcache & NFC_IPVS_PROPERTY))
                 return NF_ACCEPT;
 
 	/* The packet was sent from IPVS, exit this chain */
@@ -677,7 +678,7 @@ static int ip_vs_out_icmp(struct sk_buff **skb_p)
 		  NIPQUAD(ciph->saddr), ntohs(pptr[0]),
 		  NIPQUAD(ciph->daddr), ntohs(pptr[1]));
 
-	skb->nfmark = NFMARK_IPVS_PROPERTY;
+	skb->nfcache |= NFC_IPVS_PROPERTY;
 
 	return NF_ACCEPT;
 }
@@ -705,7 +706,7 @@ static unsigned int ip_vs_out(unsigned int hooknum,
 
 	EnterFunction(11);
 
-	if (skb->nfmark == NFMARK_IPVS_PROPERTY)
+	if (skb->nfcache & NFC_IPVS_PROPERTY)
                 return NF_ACCEPT;
 
 	iph = skb->nh.iph;
@@ -866,7 +867,7 @@ static unsigned int ip_vs_out(unsigned int hooknum,
 	ip_vs_set_state(cp, VS_STATE_OUTPUT, iph, h.portp);
 	ip_vs_conn_put(cp);
         
-	skb->nfmark = NFMARK_IPVS_PROPERTY;
+	skb->nfcache |= NFC_IPVS_PROPERTY;
 
         LeaveFunction(11);
 	return NF_ACCEPT;
@@ -890,7 +891,7 @@ unsigned int check_for_ip_vs_out(struct sk_buff **skb_p,
         } else {
                 /* send the packet immediately if it is already mangled
                    by ip_vs_out */
-                if ((*skb_p)->nfmark == NFMARK_IPVS_PROPERTY) {
+		if ((*skb_p)->nfcache & NFC_IPVS_PROPERTY) {
                         (*okfn)(*skb_p);
                         return NF_STOLEN;
                 }
@@ -975,7 +976,8 @@ static int ip_vs_in_icmp(struct sk_buff **skb_p)
                         ret = cp->packet_xmit(skb, cp);
                 else
                         ret = NF_ACCEPT;
-                ip_vs_conn_put(cp);
+		atomic_inc(&cp->in_pkts);
+		ip_vs_conn_put(cp);
                 return ret;
         }
 
@@ -1170,6 +1172,7 @@ static unsigned int ip_vs_in(unsigned int hooknum,
                         IP_VS_DBG(0, "warning: packet_xmit is null");
                         ret = NF_ACCEPT;
                 }
+		atomic_inc(&cp->in_pkts);
                 ip_vs_conn_put(cp);
                 return ret;
 	}
