@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_ctl.c,v 1.15.2.2 2001/04/20 14:33:07 wensong Exp $
+ * Version:     $Id: ip_vs_ctl.c,v 1.15.2.3 2001/05/09 08:00:16 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -73,7 +73,6 @@ static int sysctl_ip_vs_drop_packet = 0;
 static int sysctl_ip_vs_secure_tcp = 0;
 static int sysctl_ip_vs_amemthresh = 1024;
 static int sysctl_ip_vs_am_droprate = 10;
-int sysctl_use_dst = 1;
 int sysctl_ip_vs_cache_bypass = 0;
 
 #ifdef CONFIG_IP_VS_DEBUG
@@ -1276,9 +1275,6 @@ static struct ip_vs_sysctl_table ipv4_vs_table = {
           &sysctl_ip_vs_debug_level, sizeof(int), 0644, NULL,
           &proc_dointvec},
 #endif
-         {NET_IPV4_VS_USE_DST, "use_dst",
-          &sysctl_use_dst, sizeof(int), 0644, NULL,
-          &proc_dointvec},
          {NET_IPV4_VS_AMDROPRATE, "am_droprate",
           &sysctl_ip_vs_am_droprate, sizeof(int), 0644, NULL,
           &proc_dointvec},
