@@ -2,7 +2,7 @@
  *      ipvsadm - IP Virtual Server ADMinistration program
  *                for IPVS NetFilter Module in kernel 2.4
  *
- *      Version: $Id: ipvsadm.c,v 1.10 2001/04/12 02:59:31 wensong Exp $
+ *      Version: $Id: ipvsadm.c,v 1.10.2.1 2001/06/22 15:03:08 wensong Exp $
  *
  *      Authors: Wensong Zhang <wensong@linuxvirtualserver.org>
  *               Peter Kese <peter.kese@ijs.si>
@@ -422,12 +422,10 @@ int parse_options(int argc, char **argv, int reading_stdin,
 	 * but there may be others
 	 */
 	c = strlen(argv[1]);
-	if (c > 2) {
-                if(argv[1][1] != '-'){
+	if (c > 2 && argv[1][1] != '-') {
                         /* Suffle first option out of argument */
                         memmove(argv[1]+1, argv[1]+2, c-2);   
                         argv[1][c-1]='\0';
-                }
         } else {
                 /* Skip argument */
                 poptGetNextOpt(context);
